@@ -28,6 +28,7 @@
 #include <err.h>
 #include <unistd.h>
 #include <syslog.h>
+#include <fcntl.h>
 
 #include <gnome.h>
 
@@ -45,6 +46,32 @@ gboolean g_displayvars = FALSE;
 gboolean g_cshell = FALSE;
 gboolean g_quit = FALSE;
 
+/* The GPG settings we modify */
+static const gchar *confs[4] = {
+    "gpg-agent-info",
+    "use-agent",
+    "no-use-agent",
+    NULL
+};
+    
+/* Previous gpg.conf settings */
+static gchar *prev_values[4];
+
+static const struct poptOption options[] = {
+	{ "cshell", 'c', POPT_ARG_NONE | POPT_ARG_VAL, &g_cshell, TRUE,
+	  N_("Print variables in for a C type shell"), NULL },
+
+	{ "no-daemonize", 'd', POPT_ARG_NONE | POPT_ARG_VAL, &g_daemonize, FALSE,
+	  N_("Do not daemonize seahorse-agent"), NULL },
+
+	{ "variables", 'v', POPT_ARG_NONE | POPT_ARG_VAL, &g_displayvars, TRUE,
+	  N_("Display variables instead of editing gpg.conf"), NULL },
+	
+	POPT_AUTOHELP
+	
+	POPT_TABLEEND
+};
+
 /* -----------------------------------------------------------------------------
  */
 
@@ -67,22 +94,7 @@ process_display (const char *sockname, pid_t pid)
 static void
 unprocess_gpg_conf ()
 {
-    const gchar *options[3];
-    gchar *values[3];
-
-    /* This notifies GPG about us */
-    options[0] = "gpg-agent-info";
-    values[0] = NULL;
-
-    /* Make sure not using the agent */
-    options[1] = "use-agent";
-    values[1] = NULL;
-
-    /* Make sure any of the following are removed */
-    options[2] = NULL;
-    values[2] = NULL;
-
-    seahorse_gpg_options_change_vals (options, values, NULL);
+    seahorse_gpg_options_change_vals (confs, prev_values, NULL);
 }
 
 /* Add our agent info to gpg.conf */
@@ -91,31 +103,33 @@ process_gpg_conf (const char *sockname, pid_t pid)
 {
     GError *error = NULL;
     gchar *agent_info;
-    const gchar *options[4];
     gchar *values[4];
     gboolean b;
 
     g_assert (sockname && sockname[0]);
+    memset (prev_values, 0, sizeof (prev_values));
+
+    /* Read in the current values for the options */
+    if (!seahorse_gpg_options_find_vals (confs, prev_values, &error)) {
+    
+        /* Warn and put in defaults */
+        warnx (_("couldn't read gpg configuration, will try to create"));
+	  	g_clear_error (&error);
+    
+        prev_values[0] = NULL;  /* gpg-agent-info */
+        prev_values[1] = NULL;  /* use-agent */
+        prev_values[2] = NULL;  /* no-use-agent */
+        prev_values[3] = NULL;  /* null terminate */
+    }
 
     agent_info = g_strdup_printf ("%s:%lu:1", sockname, (unsigned long) pid);
-
-    /* This notifies GPG about us */
-    options[0] = "gpg-agent-info";
-    values[0] = agent_info;
-
-    /* Make sure it's using the agent */
-    options[1] = "use-agent";
-    values[1] = "";
-
-    /* Make sure any of the following are removed */
-    options[2] = "no-use-agent";
-    values[2] = NULL;
-
-    /* Null terminate the array */
-    options[3] = NULL;
-    values[3] = NULL;
-
-    b = seahorse_gpg_options_change_vals (options, values, &error);
+    
+    values[0] = agent_info;     /* gpg-agent-info */
+    values[1] = "";             /* use-agent */
+    values[2] = NULL;           /* no-use-agent */
+    values[3] = NULL;           /* null teriminate */
+    
+    b = seahorse_gpg_options_change_vals (confs, values, &error);
 
     g_free (agent_info);
 
@@ -123,7 +137,7 @@ process_gpg_conf (const char *sockname, pid_t pid)
         g_assert (error);
         errx (1, _("couldn't modify gpg configuration: %s"),
               error ? error->message : "");
-        g_error_free (error);
+        g_clear_error (&error);
     }
 }
 
@@ -152,8 +166,13 @@ daemonize (const char *sockname)
             /* Close std descriptors */
             for (i = 0; i <= 2; i++)
                 close (i);
+            
+            /* Open stdin, stdout and stderr. GPGME doesn't work without this */
+            open ("/dev/null", O_RDONLY, 0666);
+            open ("/dev/null", O_WRONLY, 0666);
+            open ("/dev/null", O_WRONLY, 0666);
 
-            chdir ("/");
+            chdir ("/tmp");
             return;
         };
     }
@@ -174,13 +193,6 @@ daemonize (const char *sockname)
         exit (0);
 }
 
-static void
-usage ()
-{
-    fprintf (stderr, _("usage: seahorse-agent [-cdv]\n"));
-    exit (2);
-}
-
 static void
 on_quit (int signal)
 {
@@ -253,53 +265,40 @@ prepare_logging ()
     g_log_set_handler ("Glib", flags, log_handler, NULL);
     g_log_set_handler ("Gtk", flags, log_handler, NULL);
     g_log_set_handler ("Gnome", flags, log_handler, NULL);
-}                
+}
 
 int
-main (int argc, char *argv[])
+main (int argc, char **argv)
 {
-    int ch = 0;
     const char *sockname;
-
+	GnomeProgram *program = NULL;
+	
     secmem_init (65536);
 
     /* We need to drop privileges completely for security */
+#if defined(HAVE_SETRESUID) && defined(HAVE_SETRESGID)
+
+    /* Not in header files for all OSs, even where present */
+    int setresuid(uid_t ruid, uid_t euid, uid_t suid);
+    int setresgid(gid_t rgid, gid_t egid, gid_t sgid);
+  
     if (setresuid (getuid (), getuid (), getuid ()) == -1 ||
         setresgid (getgid (), getgid (), getgid ()) == -1)
+#else
+    if (setuid (getuid ()) == -1 || setgid (getgid ()) == -1)
+#endif
         err (1, _("couldn't drop privileges properly"));
 
-    gtk_init (&argc, &argv);
-
-    /* Parse the arguments nicely */
-    while ((ch = getopt (argc, argv, "cdv")) != -1) {
-        switch (ch) {
-            /* Uses a C type shell */
-        case 'c':
-            g_cshell = TRUE;
-            break;
-
-            /* Don't daemonize */
-        case 'd':
-            g_daemonize = FALSE;
-            break;
-
-            /* Edit GPG conf instead of displaying vars */
-        case 'v':
-            g_displayvars = FALSE;
-            break;
-
-        case '?':
-        default:
-            usage ();
-        };
-    }
-
-    argc -= optind;
-    argv += optind;
-
-    if (argc > 0)
-        usage ();
+    program = gnome_program_init(PACKAGE, VERSION, LIBGNOMEUI_MODULE, argc, argv,
+                                 GNOME_PARAM_POPT_TABLE, options,
+                                 GNOME_PARAM_HUMAN_READABLE_NAME, _("Encryption Passphrase Agent"),
+                                 GNOME_PARAM_APP_DATADIR, DATA_DIR, NULL);
 
+#ifdef _DEBUG 
+    g_log_set_always_fatal (G_LOG_LEVEL_WARNING | G_LOG_FLAG_FATAL | 
+                            G_LOG_LEVEL_ERROR | G_LOG_LEVEL_CRITICAL);
+#endif
+    
     if (seahorse_agent_io_socket (&sockname) == -1)
         return 1;               /* message already printed */
 
@@ -325,7 +324,6 @@ main (int argc, char *argv[])
         return 1;               /* message already printed */
 
     gtk_main ();
-
     if (!g_displayvars)
         unprocess_gpg_conf ();
 
