@@ -326,7 +326,8 @@ delete_activate (GtkWidget *widget, SeahorseWidget *swidget)
         
         skey = seahorse_key_store_get_selected_key (view, &uid);
         if (uid > 0) 
-            seahorse_delete_userid_show (swidget->sctx, skey, uid);
+			/* User ids start from one in this case, strange */
+            seahorse_delete_userid_show (swidget->sctx, skey, uid + 1);
         else    
         	seahorse_delete_show (swidget->sctx, list);
 
@@ -393,13 +394,14 @@ about_activate (GtkWidget *widget, SeahorseWidget *swidget)
         "Nate Nielsen <nielsen@memberwebs.com>",
         "",
         "Contributions:",
-        "Adam Schreiber <sadam@clemson.edu>",
         "Albrecht Dreß <albrecht.dress@arcor.de>",
+        "Jim Pharis <binbrain@gmail.com>",
 		NULL
 	};
 
 	gchar *documenters[] = {
 		"Jacob Perkins <jap1@users.sourceforge.net>",
+        "Adam Schreiber <sadam@clemson.edu>",
 		NULL
 	};
 
@@ -743,7 +745,7 @@ seahorse_key_manager_show (SeahorseContext *sctx)
 
     /* To avoid flicker */
     seahorse_widget_show (swidget);
-	
+    gtk_widget_grab_focus (GTK_WIDGET (view));	
 
     /* Setup drops */
     gtk_drag_dest_set (GTK_WIDGET (win), GTK_DEST_DEFAULT_ALL, 
