@@ -253,9 +253,10 @@ edit_key (SeahorseKey *skey, SeahorseEditParm *parms, SeahorseKeyChange change)
 	/* do edit callback, release data */
 	err = gpgme_op_edit (sksrc->ctx, skey->key, seahorse_key_op_edit, parms, out);
 	gpgme_data_release (out);
-	g_return_val_if_fail (GPG_IS_OK (err), err);
+
 	/* signal key */
-	seahorse_key_changed (skey, change);
+	if(GPG_IS_OK (err))
+		seahorse_key_changed (skey, change);
 	return err;
 }
 
@@ -344,6 +345,8 @@ sign_transit (guint current_state, gpgme_status_code_t status,
 			/* if doing all uids, confirm */
 			if (status == GPGME_STATUS_GET_BOOL && g_str_equal (args, "keyedit.sign_all.okay"))
 				next_state = SIGN_CONFIRM;
+			else if (status == GPGME_STATUS_GET_BOOL && g_str_equal (args, "sign_uid.okay"))
+			    next_state = SIGN_CONFIRM;
 			/* need to do expires */
 			else if (status == GPGME_STATUS_GET_LINE && g_str_equal (args, "sign_uid.expire"))
 				next_state = SIGN_EXPIRE;
@@ -373,6 +376,8 @@ sign_transit (guint current_state, gpgme_status_code_t status,
 			/* need to do check */
 			if (status == GPGME_STATUS_GET_LINE && g_str_equal (args, "sign_uid.class"))
 				next_state = SIGN_CHECK;
+			else if (status == GPGME_STATUS_GET_BOOL && g_str_equal (args, "sign_uid.okay"))
+			    next_state = SIGN_CONFIRM;
 			/* need to do expire */
 			else if (status == GPGME_STATUS_GET_LINE && g_str_equal (args, "sign_uid.expire"))
 				next_state = SIGN_EXPIRE;
@@ -432,31 +437,28 @@ sign_transit (guint current_state, gpgme_status_code_t status,
  **/
 gpgme_error_t
 seahorse_key_op_sign (SeahorseKey *skey, const guint index,
-		              SeahorseSignCheck check, SeahorseSignOptions options)
+                      SeahorseSignCheck check, SeahorseSignOptions options)
 {
-	SignParm *sign_parm;
-	SeahorseEditParm *parms;
+    SignParm *sign_parm;
+    SeahorseEditParm *parms;
     gpgme_error_t err;
-	
-	g_return_val_if_fail (SEAHORSE_IS_KEY (skey), GPG_E (GPG_ERR_WRONG_KEY_USAGE));
-	g_return_val_if_fail (index <= seahorse_key_get_num_uids (skey), GPG_E (GPG_ERR_INV_VALUE));
-	
-	sign_parm = g_new (SignParm, 1);
-	sign_parm->index = index;
-	sign_parm->expire = ((options & SIGN_EXPIRES) != 0);
-	sign_parm->check = check;
-	sign_parm->command = "sign";
-	
-	/* if sign is local */
-	if ((options & SIGN_LOCAL) != 0)
-		sign_parm->command = g_strdup_printf ("l%s", sign_parm->command);
-	/* if sign is non-revocable */
-	if ((options & SIGN_NO_REVOKE) != 0)
-		sign_parm->command = g_strdup_printf ("nr%s", sign_parm->command);
-	
-	parms = seahorse_edit_parm_new (SIGN_START, sign_action, sign_transit, sign_parm);
-	
-	err =  edit_key (skey, parms, SKEY_CHANGE_SIGNERS);
+
+    g_return_val_if_fail (SEAHORSE_IS_KEY (skey), GPG_E (GPG_ERR_WRONG_KEY_USAGE));
+    g_return_val_if_fail (index <= seahorse_key_get_num_uids (skey), GPG_E (GPG_ERR_INV_VALUE));
+
+    sign_parm = g_new (SignParm, 1);
+    sign_parm->index = index;
+    sign_parm->expire = ((options & SIGN_EXPIRES) != 0);
+    sign_parm->check = check;
+    
+    sign_parm->command = g_strdup_printf ("%s%ssign", 
+                                (options & SIGN_NO_REVOKE) ? "nr" : "",
+                                (options & SIGN_LOCAL) ? "l" : "");
+    
+    parms = seahorse_edit_parm_new (SIGN_START, sign_action, sign_transit, sign_parm);
+
+    err =  edit_key (skey, parms, SKEY_CHANGE_SIGNERS);
+    g_free (sign_parm->command);
  
     /* If it was already signed then it's not an error */
     if (!GPG_IS_OK (err) && gpgme_err_code (err) == GPG_ERR_EALREADY)
